#
# spec file for package python-PyNaCl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-PyNaCl
Version:        1.5.0
Release:        4.1
Summary:        Python binding to the Networking and Cryptography (NaCl) library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/pyca/pynacl/
Source:         https://pypi.org/packages/source/P/PyNaCl/PyNaCl-%{version}.tar.gz
# https://github.com/pyca/pynacl/commit/a8c08b18f3a2e8f2140c531afaf42715fcab68e7
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pycparser}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libsodium) >= 1.0.18
Requires:       python-cffi
# SECTION test requirements
BuildRequires:  %{python_module hypothesis >= 3.27.0}
BuildRequires:  %{python_module pytest >= 3.2.1}
# /SECTION
%python_subpackages

%description
PyNaCl is a Python binding to the `Networking and Cryptography library`_,
a crypto library with the stated goal of improving usability, security and
speed.

%prep
%setup -q -n PyNaCl-%{version}
rm -Rf src/libsodium

%build
export SODIUM_INSTALL="system"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}/%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/*

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Sep 16 2022 pgajdos@suse.com
- python-six not required
* Thu Jul 21 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1199282, jsc#PM-3243, jsc#SLE-24629)
* Sun Jan  9 2022 Michael Ströder <michael@stroeder.com>
- Update to 1.5.0
  * Removed support for Python 2.7 and Python 3.5.
  * Changes of binary wheel distributions.
  * Update libsodium to 1.0.18-stable (July 25, 2021 release).
  * Add inline type hints.
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- six is needed by testsuite
* Sun Jul  5 2020 Michael Ströder <michael@stroeder.com>
- Update to 1.4.0
  * Update ``libsodium`` to 1.0.18.
  * **BACKWARDS INCOMPATIBLE:** We no longer distribute 32-bit ``manylinux1``
    wheels. Continuing to produce them was a maintenance burden.
  * Added support for Python 3.8, and removed support for Python 3.4.
  * Add low level bindings for extracting the seed and the public key
    from crypto_sign_ed25519 secret key
  * Add low level bindings for deterministic random generation.
  * Add ``wheel`` and ``setuptools`` setup_requirements in ``setup.py`` (#485)
  * Fix checks on very slow builders (#481, #495)
  * Add low-level bindings to ed25519 arithmetic functions
  * Update low-level blake2b state implementation
  * Fix wrong short-input behavior of SealedBox.decrypt() (#517)
  * Raise CryptPrefixError exception instead of InvalidkeyError when trying
    to check a password against a verifier stored in a unknown format (#519)
  * Add support for minimal builds of libsodium. Trying to call functions
    not available in a minimal build will raise an UnavailableError
    exception. To compile a minimal build of the bundled libsodium, set
    the SODIUM_INSTALL_MINIMAL environment variable to any non-empty
    string (e.g. ``SODIUM_INSTALL_MINIMAL=1``) for setup.
- removed obsolete back-port patch:
  * fix_tests.patch
  * hypothesis-no-unilmited.patch
  * python-PyNaCl-hypothesis-remove-average_size.patch
* Fri Apr 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix tests with latest hypothesis:
  * hypothesis-no-unilmited.patch
* Tue Jan 21 2020 pgajdos@suse.com
- python-PyNaCl requires python-cffi as demonstrated by python-dkimpy
  tests [SLE-7686] [bsc#1161557]
* Wed Sep 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add missing runtime dependency on cffi
* Thu Jul 18 2019 Ondřej Súkup <mimi.vx@gmail.com>
- add fix_tests.patch for new pytest
* Mon Jun  3 2019 pgajdos@suse.com
- run the testsuite
- added patches
  https://github.com/pyca/pynacl/commit/a8c08b18f3a2e8f2140c531afaf42715fcab68e7
  + python-PyNaCl-hypothesis-remove-average_size.patch
* Wed Dec 12 2018 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.3.0
  * Added support for Python 3.7.
  * Run and test all code examples in PyNaCl docs through sphinx's doctest
    builder.
  * Add low-level bindings for chacha20-poly1305 AEAD constructions.
  * Add low-level bindings for the chacha20-poly1305 secretstream
    constructions.
  * Add low-level bindings for ed25519ph pre-hashed signing construction.
  * Add low-level bindings for constant-time increment and addition on
    fixed-precision big integers represented as little-endian byte sequences.
  * Add low-level bindings for the ISO/IEC 7816-4 compatible padding API.
  * Add low-level bindings for libsodium's crypto_kx... key exchange
    construction.
  * Set hypothesis deadline to None in tests/test_pwhash.py to avoid incorrect
    test failures on slower processor architectures.
* Fri Dec 22 2017 mimi.vx@gmail.com
- update to 1.2.1
- use system libsodium
* Sun Jun 11 2017 mimi.vx@gmail.com
- initial import
